# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/mail/newsletter_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/mail/newsletter_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.mail import newsletter_pb2 as eolymp_dot_mail_dot_newsletter__pb2
from eolymp.mail import newsletter_recipient_pb2 as eolymp_dot_mail_dot_newsletter__recipient__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/mail/newsletter_service.proto\x12\x0b\x65olymp.mail\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/mail/newsletter.proto\x1a&eolymp/mail/newsletter_recipient.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"D\n\x15\x43reateNewsletterInput\x12+\n\nnewsletter\x18\x01 \x01(\x0b\x32\x17.eolymp.mail.Newsletter\"/\n\x16\x43reateNewsletterOutput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\"\x8f\x01\n\x15UpdateNewsletterInput\x12\x32\n\x05patch\x18\x01 \x03(\x0e\x32#.eolymp.mail.Newsletter.Patch.Field\x12\x15\n\rnewsletter_id\x18\x02 \x01(\t\x12+\n\nnewsletter\x18\x03 \x01(\x0b\x32\x17.eolymp.mail.Newsletter\"\x18\n\x16UpdateNewsletterOutput\".\n\x15\x44\x65leteNewsletterInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteNewsletterOutput\"e\n\x17\x44\x65scribeNewsletterInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x33\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32#.eolymp.mail.Newsletter.Extra.Field\"G\n\x18\x44\x65scribeNewsletterOutput\x12+\n\nnewsletter\x18\x01 \x01(\x0b\x32\x17.eolymp.mail.Newsletter\"\xa5\x03\n\x14ListNewslettersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.mail.ListNewslettersInput.Filter\x12\x0e\n\x06search\x18) \x01(\t\x12\x34\n\x04sort\x18\x32 \x01(\x0e\x32&.eolymp.mail.ListNewslettersInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12\x33\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32#.eolymp.mail.Newsletter.Extra.Field\x1a\x64\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x16\n\x04Sort\x12\x0e\n\nCREATED_AT\x10\x00\"N\n\x15ListNewslettersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.mail.Newsletter\"\xd7\x01\n\x13TestNewsletterInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x11\n\tmember_id\x18\x04 \x01(\t\x12\x44\n\nparameters\x18\x14 \x03(\x0b\x32\x30.eolymp.mail.TestNewsletterInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x16\n\x14TestNewsletterOutput\"B\n\x13SendNewsletterInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"\x16\n\x14SendNewsletterOutput\"\x84\x01\n\x18TranslateNewsletterInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x03(\t\x12\x18\n\x10target_automatic\x18\x04 \x01(\x08\x12\x17\n\x0foverride_manual\x18\x05 \x01(\x08\"+\n\x19TranslateNewsletterOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"i\n\x16\x43reateTranslationInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x38\n\x0btranslation\x18\x02 \x01(\x0b\x32#.eolymp.mail.Newsletter.Translation\"1\n\x17\x43reateTranslationOutput\x12\x16\n\x0etranslation_id\x18\x01 \x01(\t\"\xb5\x01\n\x16UpdateTranslationInput\x12\x32\n\x05patch\x18\x01 \x03(\x0e\x32#.eolymp.mail.Newsletter.Patch.Field\x12\x15\n\rnewsletter_id\x18\x02 \x01(\t\x12\x16\n\x0etranslation_id\x18\x03 \x01(\t\x12\x38\n\x0btranslation\x18\x04 \x01(\x0b\x32#.eolymp.mail.Newsletter.Translation\"\x19\n\x17UpdateTranslationOutput\"G\n\x16\x44\x65leteTranslationInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteTranslationOutput\"I\n\x18\x44\x65scribeTranslationInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"U\n\x19\x44\x65scribeTranslationOutput\x12\x38\n\x0btranslation\x18\x01 \x01(\x0b\x32#.eolymp.mail.Newsletter.Translation\"\xf0\x01\n\x15ListTranslationsInput\x12\x15\n\rnewsletter_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.mail.ListTranslationsInput.Filter\x1a\x66\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"[\n\x16ListTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x32\n\x05items\x18\x02 \x03(\x0b\x32#.eolymp.mail.Newsletter.Translation\"\xba\x01\n\x14\x43reateRecipientInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x0b \x01(\t\x12\x45\n\nparameters\x18\x14 \x03(\x0b\x32\x31.eolymp.mail.CreateRecipientInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x15\x43reateRecipientOutput\x12\x14\n\x0crecipient_id\x18\x01 \x01(\t\"\xf2\x01\n\x14ImportRecipientInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x15\n\x0b\x61ll_members\x18\n \x01(\x08H\x00\x12\x12\n\x08group_id\x18\x0b \x01(\tH\x00\x12\x14\n\ncontest_id\x18\x0c \x01(\tH\x00\x12\x45\n\nparameters\x18\x14 \x03(\x0b\x32\x31.eolymp.mail.ImportRecipientInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06source\"\x17\n\x15ImportRecipientOutput\"C\n\x14\x44\x65leteRecipientInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteRecipientOutput\"\xa0\x02\n\x13ListRecipientsInput\x12\x15\n\rnewsletter_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.mail.ListRecipientsInput.Filter\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x31\n\tmember_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"L\n\x14ListRecipientsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.mail.Recipient\"E\n\x16\x44\x65scribeRecipientInput\x12\x15\n\rnewsletter_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"D\n\x17\x44\x65scribeRecipientOutput\x12)\n\trecipient\x18\x01 \x01(\x0b\x32\x16.eolymp.mail.Recipient2\xff\x1a\n\x11NewsletterService\x12\xa3\x01\n\x10\x43reateNewsletter\x12\".eolymp.mail.CreateNewsletterInput\x1a#.eolymp.mail.CreateNewsletterOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x0e\"\x0c/newsletters\x12\xb3\x01\n\x10UpdateNewsletter\x12\".eolymp.mail.UpdateNewsletterInput\x1a#.eolymp.mail.UpdateNewsletterOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/newsletters/{newsletter_id}\x12\xb3\x01\n\x10\x44\x65leteNewsletter\x12\".eolymp.mail.DeleteNewsletterInput\x1a#.eolymp.mail.DeleteNewsletterOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1e*\x1c/newsletters/{newsletter_id}\x12\x97\x01\n\x12\x44\x65scribeNewsletter\x12$.eolymp.mail.DescribeNewsletterInput\x1a%.eolymp.mail.DescribeNewsletterOutput\"4\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x1e\x12\x1c/newsletters/{newsletter_id}\x12}\n\x0fListNewsletters\x12!.eolymp.mail.ListNewslettersInput\x1a\".eolymp.mail.ListNewslettersOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/newsletters\x12\xb2\x01\n\x0eTestNewsletter\x12 .eolymp.mail.TestNewsletterInput\x1a!.eolymp.mail.TestNewsletterOutput\"[\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02#\"!/newsletters/{newsletter_id}/test\x12\xb2\x01\n\x0eSendNewsletter\x12 .eolymp.mail.SendNewsletterInput\x1a!.eolymp.mail.SendNewsletterOutput\"[\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02#\"!/newsletters/{newsletter_id}/send\x12\xc6\x01\n\x13TranslateNewsletter\x12%.eolymp.mail.TranslateNewsletterInput\x1a&.eolymp.mail.TranslateNewsletterOutput\"`\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02(\"&/newsletters/{newsletter_id}/translate\x12\xc3\x01\n\x11\x43reateTranslation\x12#.eolymp.mail.CreateTranslationInput\x1a$.eolymp.mail.CreateTranslationOutput\"c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02+\")/newsletters/{newsletter_id}/translations\x12\xd4\x01\n\x11UpdateTranslation\x12#.eolymp.mail.UpdateTranslationInput\x1a$.eolymp.mail.UpdateTranslationOutput\"t\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02<\x1a:/newsletters/{newsletter_id}/translations/{translation_id}\x12\xd4\x01\n\x11\x44\x65leteTranslation\x12#.eolymp.mail.DeleteTranslationInput\x1a$.eolymp.mail.DeleteTranslationOutput\"t\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02<*:/newsletters/{newsletter_id}/translations/{translation_id}\x12\xda\x01\n\x13\x44\x65scribeTranslation\x12%.eolymp.mail.DescribeTranslationInput\x1a&.eolymp.mail.DescribeTranslationOutput\"t\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1e\x8a\xe3\n\x1anewsletter:newsletter:read\x82\xd3\xe4\x93\x02<\x12:/newsletters/{newsletter_id}/translations/{translation_id}\x12\xbf\x01\n\x10ListTranslations\x12\".eolymp.mail.ListTranslationsInput\x1a#.eolymp.mail.ListTranslationsOutput\"b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1e\x8a\xe3\n\x1anewsletter:newsletter:read\x82\xd3\xe4\x93\x02+\x12)/newsletters/{newsletter_id}/translations\x12\xbb\x01\n\x0f\x43reateRecipient\x12!.eolymp.mail.CreateRecipientInput\x1a\".eolymp.mail.CreateRecipientOutput\"a\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02)\"\'/newsletters/{newsletter_id}/recipients\x12\xc2\x01\n\x0fImportRecipient\x12!.eolymp.mail.ImportRecipientInput\x1a\".eolymp.mail.ImportRecipientOutput\"h\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x30\"./newsletters/{newsletter_id}/recipients:import\x12\xca\x01\n\x0f\x44\x65leteRecipient\x12!.eolymp.mail.DeleteRecipientInput\x1a\".eolymp.mail.DeleteRecipientOutput\"p\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x38*6/newsletters/{newsletter_id}/recipients/{recipient_id}\x12\xb8\x01\n\x0eListRecipients\x12 .eolymp.mail.ListRecipientsInput\x1a!.eolymp.mail.ListRecipientsOutput\"a\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02)\x12\'/newsletters/{newsletter_id}/recipients\x12\xd0\x01\n\x11\x44\x65scribeRecipient\x12#.eolymp.mail.DescribeRecipientInput\x1a$.eolymp.mail.DescribeRecipientOutput\"p\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x38\x12\x36/newsletters/{newsletter_id}/recipients/{recipient_id}\x1a\x1b\x82\xf0\xf0\xe4\x01\x15\x65olymp.universe.SpaceB+Z)github.com/eolymp/go-sdk/eolymp/mail;mailb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.mail.newsletter_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/mail;mail'
  _globals['_TESTNEWSLETTERINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_TESTNEWSLETTERINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_NEWSLETTERSERVICE']._loaded_options = None
  _globals['_NEWSLETTERSERVICE']._serialized_options = b'\202\360\360\344\001\025eolymp.universe.Space'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\016\"\014/newsletters'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['UpdateNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['UpdateNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\036\032\034/newsletters/{newsletter_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\036*\034/newsletters/{newsletter_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeNewsletter']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\036\022\034/newsletters/{newsletter_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListNewsletters']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListNewsletters']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/newsletters'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['TestNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['TestNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002#\"!/newsletters/{newsletter_id}/test'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['SendNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['SendNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002#\"!/newsletters/{newsletter_id}/send'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['TranslateNewsletter']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['TranslateNewsletter']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002(\"&/newsletters/{newsletter_id}/translate'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateTranslation']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002+\")/newsletters/{newsletter_id}/translations'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['UpdateTranslation']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['UpdateTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002<\032:/newsletters/{newsletter_id}/translations/{translation_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteTranslation']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002<*:/newsletters/{newsletter_id}/translations/{translation_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeTranslation']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeTranslation']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\036\212\343\n\032newsletter:newsletter:read\202\323\344\223\002<\022:/newsletters/{newsletter_id}/translations/{translation_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListTranslations']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListTranslations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\036\212\343\n\032newsletter:newsletter:read\202\323\344\223\002+\022)/newsletters/{newsletter_id}/translations'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateRecipient']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['CreateRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002)\"\'/newsletters/{newsletter_id}/recipients'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ImportRecipient']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ImportRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0020\"./newsletters/{newsletter_id}/recipients:import'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteRecipient']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DeleteRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0028*6/newsletters/{newsletter_id}/recipients/{recipient_id}'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListRecipients']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['ListRecipients']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002)\022\'/newsletters/{newsletter_id}/recipients'
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeRecipient']._loaded_options = None
  _globals['_NEWSLETTERSERVICE'].methods_by_name['DescribeRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0028\0226/newsletters/{newsletter_id}/recipients/{recipient_id}'
  _globals['_CREATENEWSLETTERINPUT']._serialized_start=327
  _globals['_CREATENEWSLETTERINPUT']._serialized_end=395
  _globals['_CREATENEWSLETTEROUTPUT']._serialized_start=397
  _globals['_CREATENEWSLETTEROUTPUT']._serialized_end=444
  _globals['_UPDATENEWSLETTERINPUT']._serialized_start=447
  _globals['_UPDATENEWSLETTERINPUT']._serialized_end=590
  _globals['_UPDATENEWSLETTEROUTPUT']._serialized_start=592
  _globals['_UPDATENEWSLETTEROUTPUT']._serialized_end=616
  _globals['_DELETENEWSLETTERINPUT']._serialized_start=618
  _globals['_DELETENEWSLETTERINPUT']._serialized_end=664
  _globals['_DELETENEWSLETTEROUTPUT']._serialized_start=666
  _globals['_DELETENEWSLETTEROUTPUT']._serialized_end=690
  _globals['_DESCRIBENEWSLETTERINPUT']._serialized_start=692
  _globals['_DESCRIBENEWSLETTERINPUT']._serialized_end=793
  _globals['_DESCRIBENEWSLETTEROUTPUT']._serialized_start=795
  _globals['_DESCRIBENEWSLETTEROUTPUT']._serialized_end=866
  _globals['_LISTNEWSLETTERSINPUT']._serialized_start=869
  _globals['_LISTNEWSLETTERSINPUT']._serialized_end=1290
  _globals['_LISTNEWSLETTERSINPUT_FILTER']._serialized_start=1166
  _globals['_LISTNEWSLETTERSINPUT_FILTER']._serialized_end=1266
  _globals['_LISTNEWSLETTERSINPUT_SORT']._serialized_start=1268
  _globals['_LISTNEWSLETTERSINPUT_SORT']._serialized_end=1290
  _globals['_LISTNEWSLETTERSOUTPUT']._serialized_start=1292
  _globals['_LISTNEWSLETTERSOUTPUT']._serialized_end=1370
  _globals['_TESTNEWSLETTERINPUT']._serialized_start=1373
  _globals['_TESTNEWSLETTERINPUT']._serialized_end=1588
  _globals['_TESTNEWSLETTERINPUT_PARAMETERSENTRY']._serialized_start=1539
  _globals['_TESTNEWSLETTERINPUT_PARAMETERSENTRY']._serialized_end=1588
  _globals['_TESTNEWSLETTEROUTPUT']._serialized_start=1590
  _globals['_TESTNEWSLETTEROUTPUT']._serialized_end=1612
  _globals['_SENDNEWSLETTERINPUT']._serialized_start=1614
  _globals['_SENDNEWSLETTERINPUT']._serialized_end=1680
  _globals['_SENDNEWSLETTEROUTPUT']._serialized_start=1682
  _globals['_SENDNEWSLETTEROUTPUT']._serialized_end=1704
  _globals['_TRANSLATENEWSLETTERINPUT']._serialized_start=1707
  _globals['_TRANSLATENEWSLETTERINPUT']._serialized_end=1839
  _globals['_TRANSLATENEWSLETTEROUTPUT']._serialized_start=1841
  _globals['_TRANSLATENEWSLETTEROUTPUT']._serialized_end=1884
  _globals['_CREATETRANSLATIONINPUT']._serialized_start=1886
  _globals['_CREATETRANSLATIONINPUT']._serialized_end=1991
  _globals['_CREATETRANSLATIONOUTPUT']._serialized_start=1993
  _globals['_CREATETRANSLATIONOUTPUT']._serialized_end=2042
  _globals['_UPDATETRANSLATIONINPUT']._serialized_start=2045
  _globals['_UPDATETRANSLATIONINPUT']._serialized_end=2226
  _globals['_UPDATETRANSLATIONOUTPUT']._serialized_start=2228
  _globals['_UPDATETRANSLATIONOUTPUT']._serialized_end=2253
  _globals['_DELETETRANSLATIONINPUT']._serialized_start=2255
  _globals['_DELETETRANSLATIONINPUT']._serialized_end=2326
  _globals['_DELETETRANSLATIONOUTPUT']._serialized_start=2328
  _globals['_DELETETRANSLATIONOUTPUT']._serialized_end=2353
  _globals['_DESCRIBETRANSLATIONINPUT']._serialized_start=2355
  _globals['_DESCRIBETRANSLATIONINPUT']._serialized_end=2428
  _globals['_DESCRIBETRANSLATIONOUTPUT']._serialized_start=2430
  _globals['_DESCRIBETRANSLATIONOUTPUT']._serialized_end=2515
  _globals['_LISTTRANSLATIONSINPUT']._serialized_start=2518
  _globals['_LISTTRANSLATIONSINPUT']._serialized_end=2758
  _globals['_LISTTRANSLATIONSINPUT_FILTER']._serialized_start=2656
  _globals['_LISTTRANSLATIONSINPUT_FILTER']._serialized_end=2758
  _globals['_LISTTRANSLATIONSOUTPUT']._serialized_start=2760
  _globals['_LISTTRANSLATIONSOUTPUT']._serialized_end=2851
  _globals['_CREATERECIPIENTINPUT']._serialized_start=2854
  _globals['_CREATERECIPIENTINPUT']._serialized_end=3040
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_start=1539
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_end=1588
  _globals['_CREATERECIPIENTOUTPUT']._serialized_start=3042
  _globals['_CREATERECIPIENTOUTPUT']._serialized_end=3087
  _globals['_IMPORTRECIPIENTINPUT']._serialized_start=3090
  _globals['_IMPORTRECIPIENTINPUT']._serialized_end=3332
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_start=1539
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_end=1588
  _globals['_IMPORTRECIPIENTOUTPUT']._serialized_start=3334
  _globals['_IMPORTRECIPIENTOUTPUT']._serialized_end=3357
  _globals['_DELETERECIPIENTINPUT']._serialized_start=3359
  _globals['_DELETERECIPIENTINPUT']._serialized_end=3426
  _globals['_DELETERECIPIENTOUTPUT']._serialized_start=3428
  _globals['_DELETERECIPIENTOUTPUT']._serialized_end=3451
  _globals['_LISTRECIPIENTSINPUT']._serialized_start=3454
  _globals['_LISTRECIPIENTSINPUT']._serialized_end=3742
  _globals['_LISTRECIPIENTSINPUT_FILTER']._serialized_start=3589
  _globals['_LISTRECIPIENTSINPUT_FILTER']._serialized_end=3742
  _globals['_LISTRECIPIENTSOUTPUT']._serialized_start=3744
  _globals['_LISTRECIPIENTSOUTPUT']._serialized_end=3820
  _globals['_DESCRIBERECIPIENTINPUT']._serialized_start=3822
  _globals['_DESCRIBERECIPIENTINPUT']._serialized_end=3891
  _globals['_DESCRIBERECIPIENTOUTPUT']._serialized_start=3893
  _globals['_DESCRIBERECIPIENTOUTPUT']._serialized_end=3961
  _globals['_NEWSLETTERSERVICE']._serialized_start=3964
  _globals['_NEWSLETTERSERVICE']._serialized_end=7419
# @@protoc_insertion_point(module_scope)



import datetime

from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.auth import client_pb2 as _client_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListClientsInput(_message.Message):
    __slots__ = ("offset", "size")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListClientsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_client_pb2.Client]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_client_pb2.Client, _Mapping]]] = ...) -> None: ...

class DescribeClientInput(_message.Message):
    __slots__ = ("client_id",)
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    def __init__(self, client_id: _Optional[str] = ...) -> None: ...

class DescribeClientOutput(_message.Message):
    __slots__ = ("client",)
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    client: _client_pb2.Client
    def __init__(self, client: _Optional[_Union[_client_pb2.Client, _Mapping]] = ...) -> None: ...

class CreateClientInput(_message.Message):
    __slots__ = ("client",)
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    client: _client_pb2.Client
    def __init__(self, client: _Optional[_Union[_client_pb2.Client, _Mapping]] = ...) -> None: ...

class CreateClientOutput(_message.Message):
    __slots__ = ("client_id", "secret")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    secret: str
    def __init__(self, client_id: _Optional[str] = ..., secret: _Optional[str] = ...) -> None: ...

class UpdateClientInput(_message.Message):
    __slots__ = ("patch", "client_id", "client")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_client_pb2.Client.Patch.Field]
    client_id: str
    client: _client_pb2.Client
    def __init__(self, patch: _Optional[_Iterable[_Union[_client_pb2.Client.Patch.Field, str]]] = ..., client_id: _Optional[str] = ..., client: _Optional[_Union[_client_pb2.Client, _Mapping]] = ...) -> None: ...

class UpdateClientOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteClientInput(_message.Message):
    __slots__ = ("client_id",)
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    def __init__(self, client_id: _Optional[str] = ...) -> None: ...

class DeleteClientOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ResetClientSecretInput(_message.Message):
    __slots__ = ("client_id",)
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    def __init__(self, client_id: _Optional[str] = ...) -> None: ...

class ResetClientSecretOutput(_message.Message):
    __slots__ = ("secret",)
    SECRET_FIELD_NUMBER: _ClassVar[int]
    secret: str
    def __init__(self, secret: _Optional[str] = ...) -> None: ...

class RegisterClientInput(_message.Message):
    __slots__ = ("redirect_uris", "token_endpoint_auth_method", "grant_types", "response_types", "client_name", "client_uri", "logo_uri", "scope", "contacts", "tos_uri", "policy_uri", "jwks_uri", "software_id", "software_version", "software_statement")
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ENDPOINT_AUTH_METHOD_FIELD_NUMBER: _ClassVar[int]
    GRANT_TYPES_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_TYPES_FIELD_NUMBER: _ClassVar[int]
    CLIENT_NAME_FIELD_NUMBER: _ClassVar[int]
    CLIENT_URI_FIELD_NUMBER: _ClassVar[int]
    LOGO_URI_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    CONTACTS_FIELD_NUMBER: _ClassVar[int]
    TOS_URI_FIELD_NUMBER: _ClassVar[int]
    POLICY_URI_FIELD_NUMBER: _ClassVar[int]
    JWKS_URI_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_ID_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_STATEMENT_FIELD_NUMBER: _ClassVar[int]
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    token_endpoint_auth_method: str
    grant_types: _containers.RepeatedScalarFieldContainer[str]
    response_types: _containers.RepeatedScalarFieldContainer[str]
    client_name: str
    client_uri: str
    logo_uri: str
    scope: str
    contacts: _containers.RepeatedScalarFieldContainer[str]
    tos_uri: str
    policy_uri: str
    jwks_uri: str
    software_id: str
    software_version: str
    software_statement: str
    def __init__(self, redirect_uris: _Optional[_Iterable[str]] = ..., token_endpoint_auth_method: _Optional[str] = ..., grant_types: _Optional[_Iterable[str]] = ..., response_types: _Optional[_Iterable[str]] = ..., client_name: _Optional[str] = ..., client_uri: _Optional[str] = ..., logo_uri: _Optional[str] = ..., scope: _Optional[str] = ..., contacts: _Optional[_Iterable[str]] = ..., tos_uri: _Optional[str] = ..., policy_uri: _Optional[str] = ..., jwks_uri: _Optional[str] = ..., software_id: _Optional[str] = ..., software_version: _Optional[str] = ..., software_statement: _Optional[str] = ...) -> None: ...

class RegisterClientOutput(_message.Message):
    __slots__ = ("client_id", "client_secret", "client_id_issued_at", "client_secret_expires_at", "registration_access_token", "registration_client_uri", "token_endpoint_auth_method", "application_type", "redirect_uris", "client_name", "logo_uri", "subject_type", "sector_identifier_uri", "jwks_uri", "userinfo_encrypted_response_alg", "userinfo_encrypted_response_enc", "contacts", "request_uris")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_ISSUED_AT_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    REGISTRATION_ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REGISTRATION_CLIENT_URI_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ENDPOINT_AUTH_METHOD_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    CLIENT_NAME_FIELD_NUMBER: _ClassVar[int]
    LOGO_URI_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_TYPE_FIELD_NUMBER: _ClassVar[int]
    SECTOR_IDENTIFIER_URI_FIELD_NUMBER: _ClassVar[int]
    JWKS_URI_FIELD_NUMBER: _ClassVar[int]
    USERINFO_ENCRYPTED_RESPONSE_ALG_FIELD_NUMBER: _ClassVar[int]
    USERINFO_ENCRYPTED_RESPONSE_ENC_FIELD_NUMBER: _ClassVar[int]
    CONTACTS_FIELD_NUMBER: _ClassVar[int]
    REQUEST_URIS_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_secret: str
    client_id_issued_at: _timestamp_pb2.Timestamp
    client_secret_expires_at: _timestamp_pb2.Timestamp
    registration_access_token: str
    registration_client_uri: str
    token_endpoint_auth_method: str
    application_type: str
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    client_name: str
    logo_uri: str
    subject_type: str
    sector_identifier_uri: str
    jwks_uri: str
    userinfo_encrypted_response_alg: str
    userinfo_encrypted_response_enc: str
    contacts: _containers.RepeatedScalarFieldContainer[str]
    request_uris: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, client_id: _Optional[str] = ..., client_secret: _Optional[str] = ..., client_id_issued_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., client_secret_expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., registration_access_token: _Optional[str] = ..., registration_client_uri: _Optional[str] = ..., token_endpoint_auth_method: _Optional[str] = ..., application_type: _Optional[str] = ..., redirect_uris: _Optional[_Iterable[str]] = ..., client_name: _Optional[str] = ..., logo_uri: _Optional[str] = ..., subject_type: _Optional[str] = ..., sector_identifier_uri: _Optional[str] = ..., jwks_uri: _Optional[str] = ..., userinfo_encrypted_response_alg: _Optional[str] = ..., userinfo_encrypted_response_enc: _Optional[str] = ..., contacts: _Optional[_Iterable[str]] = ..., request_uris: _Optional[_Iterable[str]] = ...) -> None: ...



from .email_service_pb2 import *
from .newsletter_pb2 import *
from .newsletter_recipient_pb2 import *
from .email_type_pb2 import *
from .newsletter_service_http import *
from .email_service_http import *
from .newsletter_service_pb2 import *



import datetime

from eolymp.annotations import mcp_pb2 as _mcp_pb2
from eolymp.universe import quota_pb2 as _quota_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Space(_message.Message):
    __slots__ = ("id", "url", "home_url", "issuer_url", "graphql_url", "key", "name", "image", "visibility", "status", "features", "subscription", "affiliation", "discord_guild_id", "locales")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Space.Status]
        TRIAL: _ClassVar[Space.Status]
        ACTIVE: _ClassVar[Space.Status]
        SUSPENDED: _ClassVar[Space.Status]
    UNKNOWN_STATUS: Space.Status
    TRIAL: Space.Status
    ACTIVE: Space.Status
    SUSPENDED: Space.Status
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_VISIBILITY: _ClassVar[Space.Visibility]
        PUBLIC: _ClassVar[Space.Visibility]
        PRIVATE: _ClassVar[Space.Visibility]
    UNKNOWN_VISIBILITY: Space.Visibility
    PUBLIC: Space.Visibility
    PRIVATE: Space.Visibility
    class Feature(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_FEATURE: _ClassVar[Space.Feature]
        PRINTERS: _ClassVar[Space.Feature]
        NEWSLETTERS: _ClassVar[Space.Feature]
        MEMBER_CREDITS: _ClassVar[Space.Feature]
        MERCHANDISE_STORE: _ClassVar[Space.Feature]
        RATING: _ClassVar[Space.Feature]
    UNKNOWN_FEATURE: Space.Feature
    PRINTERS: Space.Feature
    NEWSLETTERS: Space.Feature
    MEMBER_CREDITS: Space.Feature
    MERCHANDISE_STORE: Space.Feature
    RATING: Space.Feature
    class Extra(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_EXTRA: _ClassVar[Space.Extra.Field]
            SUBSCRIPTION: _ClassVar[Space.Extra.Field]
        UNKNOWN_EXTRA: Space.Extra.Field
        SUBSCRIPTION: Space.Extra.Field
        def __init__(self) -> None: ...
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_PATCH: _ClassVar[Space.Patch.Field]
            KEY: _ClassVar[Space.Patch.Field]
            NAME: _ClassVar[Space.Patch.Field]
            IMAGE: _ClassVar[Space.Patch.Field]
            VISIBILITY: _ClassVar[Space.Patch.Field]
            LOCALES: _ClassVar[Space.Patch.Field]
        UNKNOWN_PATCH: Space.Patch.Field
        KEY: Space.Patch.Field
        NAME: Space.Patch.Field
        IMAGE: Space.Patch.Field
        VISIBILITY: Space.Patch.Field
        LOCALES: Space.Patch.Field
        def __init__(self) -> None: ...
    class Subscription(_message.Message):
        __slots__ = ("plan", "seats", "usage", "usage_based_billing", "quota", "billing_period_start", "billing_period_end", "quota_period_start", "quota_period_end")
        PLAN_FIELD_NUMBER: _ClassVar[int]
        SEATS_FIELD_NUMBER: _ClassVar[int]
        USAGE_FIELD_NUMBER: _ClassVar[int]
        USAGE_BASED_BILLING_FIELD_NUMBER: _ClassVar[int]
        QUOTA_FIELD_NUMBER: _ClassVar[int]
        BILLING_PERIOD_START_FIELD_NUMBER: _ClassVar[int]
        BILLING_PERIOD_END_FIELD_NUMBER: _ClassVar[int]
        QUOTA_PERIOD_START_FIELD_NUMBER: _ClassVar[int]
        QUOTA_PERIOD_END_FIELD_NUMBER: _ClassVar[int]
        plan: str
        seats: int
        usage: int
        usage_based_billing: bool
        quota: _quota_pb2.Quota
        billing_period_start: _timestamp_pb2.Timestamp
        billing_period_end: _timestamp_pb2.Timestamp
        quota_period_start: _timestamp_pb2.Timestamp
        quota_period_end: _timestamp_pb2.Timestamp
        def __init__(self, plan: _Optional[str] = ..., seats: _Optional[int] = ..., usage: _Optional[int] = ..., usage_based_billing: bool = ..., quota: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ..., billing_period_start: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., billing_period_end: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., quota_period_start: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., quota_period_end: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    HOME_URL_FIELD_NUMBER: _ClassVar[int]
    ISSUER_URL_FIELD_NUMBER: _ClassVar[int]
    GRAPHQL_URL_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    AFFILIATION_FIELD_NUMBER: _ClassVar[int]
    DISCORD_GUILD_ID_FIELD_NUMBER: _ClassVar[int]
    LOCALES_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    home_url: str
    issuer_url: str
    graphql_url: str
    key: str
    name: str
    image: str
    visibility: Space.Visibility
    status: Space.Status
    features: _containers.RepeatedScalarFieldContainer[Space.Feature]
    subscription: Space.Subscription
    affiliation: str
    discord_guild_id: str
    locales: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., home_url: _Optional[str] = ..., issuer_url: _Optional[str] = ..., graphql_url: _Optional[str] = ..., key: _Optional[str] = ..., name: _Optional[str] = ..., image: _Optional[str] = ..., visibility: _Optional[_Union[Space.Visibility, str]] = ..., status: _Optional[_Union[Space.Status, str]] = ..., features: _Optional[_Iterable[_Union[Space.Feature, str]]] = ..., subscription: _Optional[_Union[Space.Subscription, _Mapping]] = ..., affiliation: _Optional[str] = ..., discord_guild_id: _Optional[str] = ..., locales: _Optional[_Iterable[str]] = ...) -> None: ...



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Profile(_message.Message):
    __slots__ = ("id", "status", "status_reason", "first_name", "last_name", "company_name", "birthday", "email", "phone", "tax_id", "country", "state", "postal_code", "city", "line1", "line2", "created_at", "updated_at")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Profile.Status]
        DRAFT: _ClassVar[Profile.Status]
        REVIEW: _ClassVar[Profile.Status]
        APPROVED: _ClassVar[Profile.Status]
        ACTIVE: _ClassVar[Profile.Status]
        REJECTED: _ClassVar[Profile.Status]
    UNKNOWN_STATUS: Profile.Status
    DRAFT: Profile.Status
    REVIEW: Profile.Status
    APPROVED: Profile.Status
    ACTIVE: Profile.Status
    REJECTED: Profile.Status
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNONWN_FIELD: _ClassVar[Profile.Patch.Field]
            FIRST_NAME: _ClassVar[Profile.Patch.Field]
            LAST_NAME: _ClassVar[Profile.Patch.Field]
            COMPANY_NAME: _ClassVar[Profile.Patch.Field]
            BIRTHDAY: _ClassVar[Profile.Patch.Field]
            EMAIL: _ClassVar[Profile.Patch.Field]
            PHONE: _ClassVar[Profile.Patch.Field]
            TAX_ID: _ClassVar[Profile.Patch.Field]
            ADDRESS: _ClassVar[Profile.Patch.Field]
        UNKNONWN_FIELD: Profile.Patch.Field
        FIRST_NAME: Profile.Patch.Field
        LAST_NAME: Profile.Patch.Field
        COMPANY_NAME: Profile.Patch.Field
        BIRTHDAY: Profile.Patch.Field
        EMAIL: Profile.Patch.Field
        PHONE: Profile.Patch.Field
        TAX_ID: Profile.Patch.Field
        ADDRESS: Profile.Patch.Field
        def __init__(self) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STATUS_REASON_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    COMPANY_NAME_FIELD_NUMBER: _ClassVar[int]
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    PHONE_FIELD_NUMBER: _ClassVar[int]
    TAX_ID_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    POSTAL_CODE_FIELD_NUMBER: _ClassVar[int]
    CITY_FIELD_NUMBER: _ClassVar[int]
    LINE1_FIELD_NUMBER: _ClassVar[int]
    LINE2_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    status: Profile.Status
    status_reason: str
    first_name: str
    last_name: str
    company_name: str
    birthday: _timestamp_pb2.Timestamp
    email: str
    phone: str
    tax_id: str
    country: str
    state: str
    postal_code: str
    city: str
    line1: str
    line2: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., status: _Optional[_Union[Profile.Status, str]] = ..., status_reason: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., company_name: _Optional[str] = ..., birthday: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., email: _Optional[str] = ..., phone: _Optional[str] = ..., tax_id: _Optional[str] = ..., country: _Optional[str] = ..., state: _Optional[str] = ..., postal_code: _Optional[str] = ..., city: _Optional[str] = ..., line1: _Optional[str] = ..., line2: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.vendor import profile_pb2 as _profile_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListVendorsInput(_message.Message):
    __slots__ = ("offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "user_id", "status", "email", "country")
        ID_FIELD_NUMBER: _ClassVar[int]
        USER_ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        EMAIL_FIELD_NUMBER: _ClassVar[int]
        COUNTRY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        user_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        email: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        country: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., user_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., email: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., country: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListVendorsInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListVendorsInput.Filter, _Mapping]] = ...) -> None: ...

class ListVendorsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_profile_pb2.Profile]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_profile_pb2.Profile, _Mapping]]] = ...) -> None: ...

class DescribeVendorInput(_message.Message):
    __slots__ = ("vendor_id",)
    VENDOR_ID_FIELD_NUMBER: _ClassVar[int]
    vendor_id: str
    def __init__(self, vendor_id: _Optional[str] = ...) -> None: ...

class DescribeVendorOutput(_message.Message):
    __slots__ = ("profile",)
    PROFILE_FIELD_NUMBER: _ClassVar[int]
    profile: _profile_pb2.Profile
    def __init__(self, profile: _Optional[_Union[_profile_pb2.Profile, _Mapping]] = ...) -> None: ...

class ApproveVendorInput(_message.Message):
    __slots__ = ("vendor_id", "comment")
    VENDOR_ID_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    vendor_id: str
    comment: str
    def __init__(self, vendor_id: _Optional[str] = ..., comment: _Optional[str] = ...) -> None: ...

class ApproveVendorOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RejectVendorInput(_message.Message):
    __slots__ = ("vendor_id", "comment")
    VENDOR_ID_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    vendor_id: str
    comment: str
    def __init__(self, vendor_id: _Optional[str] = ..., comment: _Optional[str] = ...) -> None: ...

class RejectVendorOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/vendor/profile_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/vendor/profile_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.vendor import profile_pb2 as eolymp_dot_vendor_dot_profile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/vendor/profile_service.proto\x12\reolymp.vendor\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/vendor/profile.proto\"\x16\n\x14\x44\x65scribeProfileInput\"@\n\x15\x44\x65scribeProfileOutput\x12\'\n\x07profile\x18\x01 \x01(\x0b\x32\x16.eolymp.vendor.Profile\"p\n\x12UpdateProfileInput\x12\x31\n\x05patch\x18\x01 \x03(\x0e\x32\".eolymp.vendor.Profile.Patch.Field\x12\'\n\x07profile\x18\x02 \x01(\x0b\x32\x16.eolymp.vendor.Profile\"\x15\n\x13UpdateProfileOutput\"\x14\n\x12SubmitProfileInput\"\x15\n\x13SubmitProfileOutput2\xf6\x03\n\x0eProfileService\x12\xa0\x01\n\x0f\x44\x65scribeProfile\x12#.eolymp.vendor.DescribeProfileInput\x1a$.eolymp.vendor.DescribeProfileOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13vendor:profile:read\x82\xd3\xe4\x93\x02\x12\x12\x10/vendor/profiles\x12\x9b\x01\n\rUpdateProfile\x12!.eolymp.vendor.UpdateProfileInput\x1a\".eolymp.vendor.UpdateProfileOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\x12\x1a\x10/vendor/profiles\x12\xa2\x01\n\rSubmitProfile\x12!.eolymp.vendor.SubmitProfileInput\x1a\".eolymp.vendor.SubmitProfileOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\x19\"\x17/vendor/profiles:submitB/Z-github.com/eolymp/go-sdk/eolymp/vendor;vendorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.vendor.profile_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/vendor;vendor'
  _globals['_PROFILESERVICE'].methods_by_name['DescribeProfile']._loaded_options = None
  _globals['_PROFILESERVICE'].methods_by_name['DescribeProfile']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023vendor:profile:read\202\323\344\223\002\022\022\020/vendor/profiles'
  _globals['_PROFILESERVICE'].methods_by_name['UpdateProfile']._loaded_options = None
  _globals['_PROFILESERVICE'].methods_by_name['UpdateProfile']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\022\032\020/vendor/profiles'
  _globals['_PROFILESERVICE'].methods_by_name['SubmitProfile']._loaded_options = None
  _globals['_PROFILESERVICE'].methods_by_name['SubmitProfile']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\031\"\027/vendor/profiles:submit'
  _globals['_DESCRIBEPROFILEINPUT']._serialized_start=182
  _globals['_DESCRIBEPROFILEINPUT']._serialized_end=204
  _globals['_DESCRIBEPROFILEOUTPUT']._serialized_start=206
  _globals['_DESCRIBEPROFILEOUTPUT']._serialized_end=270
  _globals['_UPDATEPROFILEINPUT']._serialized_start=272
  _globals['_UPDATEPROFILEINPUT']._serialized_end=384
  _globals['_UPDATEPROFILEOUTPUT']._serialized_start=386
  _globals['_UPDATEPROFILEOUTPUT']._serialized_end=407
  _globals['_SUBMITPROFILEINPUT']._serialized_start=409
  _globals['_SUBMITPROFILEINPUT']._serialized_end=429
  _globals['_SUBMITPROFILEOUTPUT']._serialized_start=431
  _globals['_SUBMITPROFILEOUTPUT']._serialized_end=452
  _globals['_PROFILESERVICE']._serialized_start=455
  _globals['_PROFILESERVICE']._serialized_end=957
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/form.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/form.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65olymp/atlas/form.proto\x12\x0c\x65olymp.atlas\"\xec\x05\n\x04\x46orm\x12(\n\x06\x66ields\x18\n \x03(\x0b\x32\x18.eolymp.atlas.Form.Field\x1a\xad\x03\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12+\n\x04type\x18\x03 \x01(\x0e\x32\x1d.eolymp.atlas.Form.Field.Type\x12-\n\x04\x63ode\x18\x65 \x01(\x0b\x32\x1d.eolymp.atlas.Form.Field.CodeH\x00\x12-\n\x04\x66ile\x18\x66 \x01(\x0b\x32\x1d.eolymp.atlas.Form.Field.FileH\x00\x1a\x87\x01\n\x04\x43ode\x12\x10\n\x08runtimes\x18\x01 \x03(\t\x12\x17\n\x0fmax_attachments\x18\x02 \x01(\r\x12\x1b\n\x13\x61ttachment_max_size\x18\x05 \x01(\r\x12\x18\n\x10\x61ttachment_types\x18\x03 \x03(\t\x12\x1d\n\x15\x61ttachment_extensions\x18\x04 \x03(\t\x1a;\n\x04\x46ile\x12\r\n\x05types\x18\x01 \x03(\t\x12\x12\n\nextensions\x18\x02 \x03(\t\x12\x10\n\x08max_size\x18\x03 \x01(\r\",\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x08\n\x04\x43ODE\x10\x01\x12\x08\n\x04\x46ILE\x10\x02\x42\x07\n\x05input\x1a\x89\x02\n\x05Value\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x04\x63ode\x18\n \x01(\x0b\x32\x1d.eolymp.atlas.Form.Value.CodeH\x00\x12-\n\x04\x66ile\x18\x0b \x01(\x0b\x32\x1d.eolymp.atlas.Form.Value.FileH\x00\x1a_\n\x04\x43ode\x12\x0f\n\x07runtime\x18\x01 \x01(\t\x12\x12\n\nsource_url\x18\x02 \x01(\t\x12\x32\n\x0b\x61ttachments\x18\x03 \x03(\x0b\x32\x1d.eolymp.atlas.Form.Value.File\x1a*\n\x04\x46ile\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61ta_url\x18\x02 \x01(\tB\x07\n\x05valueB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.form_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_FORM']._serialized_start=42
  _globals['_FORM']._serialized_end=790
  _globals['_FORM_FIELD']._serialized_start=93
  _globals['_FORM_FIELD']._serialized_end=522
  _globals['_FORM_FIELD_CODE']._serialized_start=271
  _globals['_FORM_FIELD_CODE']._serialized_end=406
  _globals['_FORM_FIELD_FILE']._serialized_start=408
  _globals['_FORM_FIELD_FILE']._serialized_end=467
  _globals['_FORM_FIELD_TYPE']._serialized_start=469
  _globals['_FORM_FIELD_TYPE']._serialized_end=513
  _globals['_FORM_VALUE']._serialized_start=525
  _globals['_FORM_VALUE']._serialized_end=790
  _globals['_FORM_VALUE_CODE']._serialized_start=642
  _globals['_FORM_VALUE_CODE']._serialized_end=737
  _globals['_FORM_VALUE_FILE']._serialized_start=739
  _globals['_FORM_VALUE_FILE']._serialized_end=781
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import namespace_pb2 as _namespace_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TranslateContentInput(_message.Message):
    __slots__ = ("content",)
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    content: _content_pb2.Content
    def __init__(self, content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class TranslateContentOutput(_message.Message):
    __slots__ = ("translation",)
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    translation: _content_pb2.Content
    def __init__(self, translation: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/submission_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/submission_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import mcp_pb2 as eolymp_dot_annotations_dot_mcp__pb2
from eolymp.annotations import namespace_pb2 as eolymp_dot_annotations_dot_namespace__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import form_pb2 as eolymp_dot_atlas_dot_form__pb2
from eolymp.judge import submission_pb2 as eolymp_dot_judge_dot_submission__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/judge/submission_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1c\x65olymp/annotations/mcp.proto\x1a\"eolymp/annotations/namespace.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x17\x65olymp/atlas/form.proto\x1a\x1d\x65olymp/judge/submission.proto\x1a!eolymp/wellknown/expression.proto\"\x87\x01\n\x15\x43reateSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0c\n\x04lang\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12(\n\x06values\x18\x05 \x03(\x0b\x32\x18.eolymp.atlas.Form.Value\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"\x99\x07\n\x14ListSubmissionsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.judge.ListSubmissionsInput.Filter\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.judge.Submission.Extra\x1a\xd3\x05\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\nproblem_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\xf4\x01\n\x06status\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnumB\xc1\x01\xa2\xf0\xf0\xe4\x01\xba\x01valid values `PENDING`, `PROVISIONING`, `INITIALIZING`, `TESTING`, `COMPLETE` (testing complete), `TIMEOUT` (took too long to test), `ERROR` (compilation error), `FAILURE` (system error)\x12@\n\x04lang\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnumB\x10\xa2\xf0\xf0\xe4\x01\nruntime id\x12\x30\n\x05score\x18\x06 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x35\n\npercentage\x18\x07 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12;\n\x0csubmitted_at\x18\x08 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12R\n\tsignature\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnumB\x1d\xa2\xf0\xf0\xe4\x01\x17source code fingerprint\"i\n\x15ListSubmissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.judge.Submission\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\"t\n\x17\x44\x65scribeSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.judge.Submission.Extra\"H\n\x18\x44\x65scribeSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\"A\n\x14PrintSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"\x17\n\x15PrintSubmissionOutput\"q\n\x14WatchSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.judge.Submission.Extra\"E\n\x15WatchSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\"B\n\x15RetestSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"\x18\n\x16RetestSubmissionOutput\"B\n\x15\x44\x65leteSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteSubmissionOutput\"C\n\x16RestoreSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"\x19\n\x17RestoreSubmissionOutput\"<\n\x12RetestProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"\x15\n\x13RetestProblemOutput\"/\n\x16\x41nalyzeSubmissionInput\x12\x15\n\rsubmission_id\x18\n \x01(\t\"\x19\n\x17\x41nalyzeSubmissionOutput2\xf4\r\n\x11SubmissionService\x12\xc0\x01\n\x10\x43reateSubmission\x12#.eolymp.judge.CreateSubmissionInput\x1a$.eolymp.judge.CreateSubmissionOutput\"a\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02+\"\"/problems/{problem_id}/submissions\x98\xe3\n\x80\x80\xc0\x02\x12\x99\x01\n\x0fListSubmissions\x12\".eolymp.judge.ListSubmissionsInput\x1a#.eolymp.judge.ListSubmissionsOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x0e\x12\x0c/submissions\x12\xb2\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.judge.DescribeSubmissionInput\x1a&.eolymp.judge.DescribeSubmissionOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/submissions/{submission_id}\x12\xaf\x01\n\x0fPrintSubmission\x12\".eolymp.judge.PrintSubmissionInput\x1a#.eolymp.judge.PrintSubmissionOutput\"S\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02$\"\"/submissions/{submission_id}/print\x12x\n\x0fWatchSubmission\x12\".eolymp.judge.WatchSubmissionInput\x1a#.eolymp.judge.WatchSubmissionOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\xb4\x01\n\x10RetestSubmission\x12#.eolymp.judge.RetestSubmissionInput\x1a$.eolymp.judge.RetestSubmissionOutput\"U\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02%\"#/submissions/{submission_id}/retest\x12\xad\x01\n\x10\x44\x65leteSubmission\x12#.eolymp.judge.DeleteSubmissionInput\x1a$.eolymp.judge.DeleteSubmissionOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1e*\x1c/submissions/{submission_id}\x12\xb8\x01\n\x11RestoreSubmission\x12$.eolymp.judge.RestoreSubmissionInput\x1a%.eolymp.judge.RestoreSubmissionOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02&\"$/submissions/{submission_id}/restore\x12\xa5\x01\n\rRetestProblem\x12 .eolymp.judge.RetestProblemInput\x1a!.eolymp.judge.RetestProblemOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1f\x12\x1d/problems/{problem_id}/retest\x12\xb8\x01\n\x11\x41nalyzeSubmission\x12$.eolymp.judge.AnalyzeSubmissionInput\x1a%.eolymp.judge.AnalyzeSubmissionOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02&\"$/submissions/{submission_id}/analyze\x1a\x1a\x82\xf0\xf0\xe4\x01\x14\x65olymp.judge.ContestB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.submission_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_LISTSUBMISSIONSINPUT_FILTER'].fields_by_name['status']._loaded_options = None
  _globals['_LISTSUBMISSIONSINPUT_FILTER'].fields_by_name['status']._serialized_options = b'\242\360\360\344\001\272\001valid values `PENDING`, `PROVISIONING`, `INITIALIZING`, `TESTING`, `COMPLETE` (testing complete), `TIMEOUT` (took too long to test), `ERROR` (compilation error), `FAILURE` (system error)'
  _globals['_LISTSUBMISSIONSINPUT_FILTER'].fields_by_name['lang']._loaded_options = None
  _globals['_LISTSUBMISSIONSINPUT_FILTER'].fields_by_name['lang']._serialized_options = b'\242\360\360\344\001\nruntime id'
  _globals['_LISTSUBMISSIONSINPUT_FILTER'].fields_by_name['signature']._loaded_options = None
  _globals['_LISTSUBMISSIONSINPUT_FILTER'].fields_by_name['signature']._serialized_options = b'\242\360\360\344\001\027source code fingerprint'
  _globals['_SUBMISSIONSERVICE']._loaded_options = None
  _globals['_SUBMISSIONSERVICE']._serialized_options = b'\202\360\360\344\001\024eolymp.judge.Contest'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['CreateSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['CreateSubmission']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002+\"\"/problems/{problem_id}/submissions\230\343\n\200\200\300\002'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['ListSubmissions']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['ListSubmissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\016\022\014/submissions'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['DescribeSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['DescribeSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\036\022\034/submissions/{submission_id}'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['PrintSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['PrintSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002$\"\"/submissions/{submission_id}/print'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['WatchSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['WatchSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['RetestSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['RetestSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002%\"#/submissions/{submission_id}/retest'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['DeleteSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['DeleteSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\036*\034/submissions/{submission_id}'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['RestoreSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['RestoreSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002&\"$/submissions/{submission_id}/restore'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['RetestProblem']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['RetestProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\037\022\035/problems/{problem_id}/retest'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['AnalyzeSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['AnalyzeSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002&\"$/submissions/{submission_id}/analyze'
  _globals['_CREATESUBMISSIONINPUT']._serialized_start=312
  _globals['_CREATESUBMISSIONINPUT']._serialized_end=447
  _globals['_CREATESUBMISSIONOUTPUT']._serialized_start=449
  _globals['_CREATESUBMISSIONOUTPUT']._serialized_end=496
  _globals['_LISTSUBMISSIONSINPUT']._serialized_start=499
  _globals['_LISTSUBMISSIONSINPUT']._serialized_end=1420
  _globals['_LISTSUBMISSIONSINPUT_FILTER']._serialized_start=697
  _globals['_LISTSUBMISSIONSINPUT_FILTER']._serialized_end=1420
  _globals['_LISTSUBMISSIONSOUTPUT']._serialized_start=1422
  _globals['_LISTSUBMISSIONSOUTPUT']._serialized_end=1527
  _globals['_DESCRIBESUBMISSIONINPUT']._serialized_start=1529
  _globals['_DESCRIBESUBMISSIONINPUT']._serialized_end=1645
  _globals['_DESCRIBESUBMISSIONOUTPUT']._serialized_start=1647
  _globals['_DESCRIBESUBMISSIONOUTPUT']._serialized_end=1719
  _globals['_PRINTSUBMISSIONINPUT']._serialized_start=1721
  _globals['_PRINTSUBMISSIONINPUT']._serialized_end=1786
  _globals['_PRINTSUBMISSIONOUTPUT']._serialized_start=1788
  _globals['_PRINTSUBMISSIONOUTPUT']._serialized_end=1811
  _globals['_WATCHSUBMISSIONINPUT']._serialized_start=1813
  _globals['_WATCHSUBMISSIONINPUT']._serialized_end=1926
  _globals['_WATCHSUBMISSIONOUTPUT']._serialized_start=1928
  _globals['_WATCHSUBMISSIONOUTPUT']._serialized_end=1997
  _globals['_RETESTSUBMISSIONINPUT']._serialized_start=1999
  _globals['_RETESTSUBMISSIONINPUT']._serialized_end=2065
  _globals['_RETESTSUBMISSIONOUTPUT']._serialized_start=2067
  _globals['_RETESTSUBMISSIONOUTPUT']._serialized_end=2091
  _globals['_DELETESUBMISSIONINPUT']._serialized_start=2093
  _globals['_DELETESUBMISSIONINPUT']._serialized_end=2159
  _globals['_DELETESUBMISSIONOUTPUT']._serialized_start=2161
  _globals['_DELETESUBMISSIONOUTPUT']._serialized_end=2185
  _globals['_RESTORESUBMISSIONINPUT']._serialized_start=2187
  _globals['_RESTORESUBMISSIONINPUT']._serialized_end=2254
  _globals['_RESTORESUBMISSIONOUTPUT']._serialized_start=2256
  _globals['_RESTORESUBMISSIONOUTPUT']._serialized_end=2281
  _globals['_RETESTPROBLEMINPUT']._serialized_start=2283
  _globals['_RETESTPROBLEMINPUT']._serialized_end=2343
  _globals['_RETESTPROBLEMOUTPUT']._serialized_start=2345
  _globals['_RETESTPROBLEMOUTPUT']._serialized_end=2366
  _globals['_ANALYZESUBMISSIONINPUT']._serialized_start=2368
  _globals['_ANALYZESUBMISSIONINPUT']._serialized_end=2415
  _globals['_ANALYZESUBMISSIONOUTPUT']._serialized_start=2417
  _globals['_ANALYZESUBMISSIONOUTPUT']._serialized_end=2442
  _globals['_SUBMISSIONSERVICE']._serialized_start=2445
  _globals['_SUBMISSIONSERVICE']._serialized_end=4225
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class LookupAddressInput(_message.Message):
    __slots__ = ("ip_address", "secret")
    IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    ip_address: str
    secret: str
    def __init__(self, ip_address: _Optional[str] = ..., secret: _Optional[str] = ...) -> None: ...

class LookupAddressOutput(_message.Message):
    __slots__ = ("latitude", "longitude", "country", "timezone", "postcode", "city", "region")
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    TIMEZONE_FIELD_NUMBER: _ClassVar[int]
    POSTCODE_FIELD_NUMBER: _ClassVar[int]
    CITY_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    latitude: float
    longitude: float
    country: str
    timezone: str
    postcode: str
    city: str
    region: str
    def __init__(self, latitude: _Optional[float] = ..., longitude: _Optional[float] = ..., country: _Optional[str] = ..., timezone: _Optional[str] = ..., postcode: _Optional[str] = ..., city: _Optional[str] = ..., region: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/vendor/invoice_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/vendor/invoice_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.vendor import invoice_pb2 as eolymp_dot_vendor_dot_invoice__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/vendor/invoice_service.proto\x12\reolymp.vendor\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/vendor/invoice.proto\x1a!eolymp/wellknown/expression.proto\"\xca\x02\n\x11ListInvoicesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.vendor.ListInvoicesInput.Filter\x1a\xcd\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\x06number\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x31\n\tvendor_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"J\n\x12ListInvoicesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.vendor.Invoice\"*\n\x14\x44\x65scribeInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\"@\n\x15\x44\x65scribeInvoiceOutput\x12\'\n\x07invoice\x18\x01 \x01(\x0b\x32\x16.eolymp.vendor.Invoice\"=\n\x12\x43reateInvoiceInput\x12\'\n\x07invoice\x18\x01 \x01(\x0b\x32\x16.eolymp.vendor.Invoice\")\n\x13\x43reateInvoiceOutput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\"\x84\x01\n\x12UpdateInvoiceInput\x12\x31\n\x05patch\x18\x01 \x03(\x0e\x32\".eolymp.vendor.Invoice.Patch.Field\x12\x12\n\ninvoice_id\x18\x02 \x01(\t\x12\'\n\x07invoice\x18\x03 \x01(\x0b\x32\x16.eolymp.vendor.Invoice\"\x15\n\x13UpdateInvoiceOutput\"(\n\x12\x44\x65leteInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteInvoiceOutput\"P\n\x1aUploadInvoiceDocumentInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"3\n\x1bUploadInvoiceDocumentOutput\x12\x14\n\x0c\x64ocument_url\x18\x01 \x01(\t\":\n\x13\x41pproveInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x16\n\x14\x41pproveInvoiceOutput\"(\n\x12SubmitInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\"\x15\n\x13SubmitInvoiceOutput\"9\n\x12RejectInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x15\n\x13RejectInvoiceOutput2\xbb\x0c\n\x0eInvoiceService\x12\x97\x01\n\x0cListInvoices\x12 .eolymp.vendor.ListInvoicesInput\x1a!.eolymp.vendor.ListInvoicesOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13vendor:profile:read\x82\xd3\xe4\x93\x02\x12\x12\x10/vendor/invoices\x12\xad\x01\n\x0f\x44\x65scribeInvoice\x12#.eolymp.vendor.DescribeInvoiceInput\x1a$.eolymp.vendor.DescribeInvoiceOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13vendor:profile:read\x82\xd3\xe4\x93\x02\x1f\x12\x1d/vendor/invoices/{invoice_id}\x12\x9b\x01\n\rCreateInvoice\x12!.eolymp.vendor.CreateInvoiceInput\x1a\".eolymp.vendor.CreateInvoiceOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\x12\"\x10/vendor/invoices\x12\xa8\x01\n\rUpdateInvoice\x12!.eolymp.vendor.UpdateInvoiceInput\x1a\".eolymp.vendor.UpdateInvoiceOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/vendor/invoices/{invoice_id}\x12\xa8\x01\n\rDeleteInvoice\x12!.eolymp.vendor.DeleteInvoiceInput\x1a\".eolymp.vendor.DeleteInvoiceOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\x1f*\x1d/vendor/invoices/{invoice_id}\x12\xd0\x01\n\x15UploadInvoiceDocument\x12).eolymp.vendor.UploadInvoiceDocumentInput\x1a*.eolymp.vendor.UploadInvoiceDocumentOutput\"`\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02/\"&/vendor/invoices/{invoice_id}/document\x98\xe3\n\x80\x80\x80\x01\x12\xaf\x01\n\rSubmitInvoice\x12!.eolymp.vendor.SubmitInvoiceInput\x1a\".eolymp.vendor.SubmitInvoiceOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02&\"$/vendor/invoices/{invoice_id}/submit\x12\xb3\x01\n\x0e\x41pproveInvoice\x12\".eolymp.vendor.ApproveInvoiceInput\x1a#.eolymp.vendor.ApproveInvoiceOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02\'\"%/vendor/invoices/{invoice_id}/approve\x12\xaf\x01\n\rRejectInvoice\x12!.eolymp.vendor.RejectInvoiceInput\x1a\".eolymp.vendor.RejectInvoiceOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14vendor:profile:write\x82\xd3\xe4\x93\x02&\"$/vendor/invoices/{invoice_id}/rejectB/Z-github.com/eolymp/go-sdk/eolymp/vendor;vendorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.vendor.invoice_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/vendor;vendor'
  _globals['_INVOICESERVICE'].methods_by_name['ListInvoices']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['ListInvoices']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023vendor:profile:read\202\323\344\223\002\022\022\020/vendor/invoices'
  _globals['_INVOICESERVICE'].methods_by_name['DescribeInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['DescribeInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023vendor:profile:read\202\323\344\223\002\037\022\035/vendor/invoices/{invoice_id}'
  _globals['_INVOICESERVICE'].methods_by_name['CreateInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['CreateInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\022\"\020/vendor/invoices'
  _globals['_INVOICESERVICE'].methods_by_name['UpdateInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['UpdateInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\037\032\035/vendor/invoices/{invoice_id}'
  _globals['_INVOICESERVICE'].methods_by_name['DeleteInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['DeleteInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\037*\035/vendor/invoices/{invoice_id}'
  _globals['_INVOICESERVICE'].methods_by_name['UploadInvoiceDocument']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['UploadInvoiceDocument']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002/\"&/vendor/invoices/{invoice_id}/document\230\343\n\200\200\200\001'
  _globals['_INVOICESERVICE'].methods_by_name['SubmitInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['SubmitInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002&\"$/vendor/invoices/{invoice_id}/submit'
  _globals['_INVOICESERVICE'].methods_by_name['ApproveInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['ApproveInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002\'\"%/vendor/invoices/{invoice_id}/approve'
  _globals['_INVOICESERVICE'].methods_by_name['RejectInvoice']._loaded_options = None
  _globals['_INVOICESERVICE'].methods_by_name['RejectInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024vendor:profile:write\202\323\344\223\002&\"$/vendor/invoices/{invoice_id}/reject'
  _globals['_LISTINVOICESINPUT']._serialized_start=218
  _globals['_LISTINVOICESINPUT']._serialized_end=548
  _globals['_LISTINVOICESINPUT_FILTER']._serialized_start=343
  _globals['_LISTINVOICESINPUT_FILTER']._serialized_end=548
  _globals['_LISTINVOICESOUTPUT']._serialized_start=550
  _globals['_LISTINVOICESOUTPUT']._serialized_end=624
  _globals['_DESCRIBEINVOICEINPUT']._serialized_start=626
  _globals['_DESCRIBEINVOICEINPUT']._serialized_end=668
  _globals['_DESCRIBEINVOICEOUTPUT']._serialized_start=670
  _globals['_DESCRIBEINVOICEOUTPUT']._serialized_end=734
  _globals['_CREATEINVOICEINPUT']._serialized_start=736
  _globals['_CREATEINVOICEINPUT']._serialized_end=797
  _globals['_CREATEINVOICEOUTPUT']._serialized_start=799
  _globals['_CREATEINVOICEOUTPUT']._serialized_end=840
  _globals['_UPDATEINVOICEINPUT']._serialized_start=843
  _globals['_UPDATEINVOICEINPUT']._serialized_end=975
  _globals['_UPDATEINVOICEOUTPUT']._serialized_start=977
  _globals['_UPDATEINVOICEOUTPUT']._serialized_end=998
  _globals['_DELETEINVOICEINPUT']._serialized_start=1000
  _globals['_DELETEINVOICEINPUT']._serialized_end=1040
  _globals['_DELETEINVOICEOUTPUT']._serialized_start=1042
  _globals['_DELETEINVOICEOUTPUT']._serialized_end=1063
  _globals['_UPLOADINVOICEDOCUMENTINPUT']._serialized_start=1065
  _globals['_UPLOADINVOICEDOCUMENTINPUT']._serialized_end=1145
  _globals['_UPLOADINVOICEDOCUMENTOUTPUT']._serialized_start=1147
  _globals['_UPLOADINVOICEDOCUMENTOUTPUT']._serialized_end=1198
  _globals['_APPROVEINVOICEINPUT']._serialized_start=1200
  _globals['_APPROVEINVOICEINPUT']._serialized_end=1258
  _globals['_APPROVEINVOICEOUTPUT']._serialized_start=1260
  _globals['_APPROVEINVOICEOUTPUT']._serialized_end=1282
  _globals['_SUBMITINVOICEINPUT']._serialized_start=1284
  _globals['_SUBMITINVOICEINPUT']._serialized_end=1324
  _globals['_SUBMITINVOICEOUTPUT']._serialized_start=1326
  _globals['_SUBMITINVOICEOUTPUT']._serialized_end=1347
  _globals['_REJECTINVOICEINPUT']._serialized_start=1349
  _globals['_REJECTINVOICEINPUT']._serialized_end=1406
  _globals['_REJECTINVOICEOUTPUT']._serialized_start=1408
  _globals['_REJECTINVOICEOUTPUT']._serialized_end=1429
  _globals['_INVOICESERVICE']._serialized_start=1432
  _globals['_INVOICESERVICE']._serialized_end=3027
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
MCP_VALUE_DESC_FIELD_NUMBER: _ClassVar[int]
mcp_value_desc: _descriptor.FieldDescriptor
MCP_VALUE_IGNORE_FIELD_NUMBER: _ClassVar[int]
mcp_value_ignore: _descriptor.FieldDescriptor
MCP_FIELD_DESC_FIELD_NUMBER: _ClassVar[int]
mcp_field_desc: _descriptor.FieldDescriptor
MCP_FIELD_IGNORE_FIELD_NUMBER: _ClassVar[int]
mcp_field_ignore: _descriptor.FieldDescriptor
READ_ONLY_FIELD_NUMBER: _ClassVar[int]
read_only: _descriptor.FieldDescriptor
MCP_TOOL_DESC_FIELD_NUMBER: _ClassVar[int]
mcp_tool_desc: _descriptor.FieldDescriptor



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Client(_message.Message):
    __slots__ = ("id", "secret", "name", "redirect_uri", "created_at", "updated_at")
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            UNKNOWN_FIELD: _ClassVar[Client.Patch.Field]
            NAME: _ClassVar[Client.Patch.Field]
            REDIRECT_URI: _ClassVar[Client.Patch.Field]
        UNKNOWN_FIELD: Client.Patch.Field
        NAME: Client.Patch.Field
        REDIRECT_URI: Client.Patch.Field
        def __init__(self) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    secret: str
    name: str
    redirect_uri: _containers.RepeatedScalarFieldContainer[str]
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., secret: _Optional[str] = ..., name: _Optional[str] = ..., redirect_uri: _Optional[_Iterable[str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



import datetime

from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import namespace_pb2 as _namespace_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AllocateStockInput(_message.Message):
    __slots__ = ("order_id",)
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    order_id: str
    def __init__(self, order_id: _Optional[str] = ...) -> None: ...

class AllocateStockOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RejectOrderInput(_message.Message):
    __slots__ = ("order_id", "reason")
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    order_id: str
    reason: _content_pb2.Content
    def __init__(self, order_id: _Optional[str] = ..., reason: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...

class RejectOrderOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ProcessOrderInput(_message.Message):
    __slots__ = ("order_id", "estimated_shipping_date")
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    ESTIMATED_SHIPPING_DATE_FIELD_NUMBER: _ClassVar[int]
    order_id: str
    estimated_shipping_date: _timestamp_pb2.Timestamp
    def __init__(self, order_id: _Optional[str] = ..., estimated_shipping_date: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ProcessOrderOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ShipOrderInput(_message.Message):
    __slots__ = ("order_id", "tracking_link", "tracking_number")
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    TRACKING_LINK_FIELD_NUMBER: _ClassVar[int]
    TRACKING_NUMBER_FIELD_NUMBER: _ClassVar[int]
    order_id: str
    tracking_link: str
    tracking_number: str
    def __init__(self, order_id: _Optional[str] = ..., tracking_link: _Optional[str] = ..., tracking_number: _Optional[str] = ...) -> None: ...

class ShipOrderOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CompleteOrderInput(_message.Message):
    __slots__ = ("order_id",)
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    order_id: str
    def __init__(self, order_id: _Optional[str] = ...) -> None: ...

class CompleteOrderOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...
